@@ -62,11 +62,14 @@ class WidgetList(scrolledpanel.ScrolledPanel):
     """Border and title background colour for widget groups. """
 
 
-    def __init__(self, parent, style=0):
+    def __init__(self, parent, style=0, minHeight=-1):
         """Create a ``WidgetList``.
 
-        :arg parent: The :mod:`wx` parent object.
+        :arg parent:    The :mod:`wx` parent object.
+        :arg style:     Passed through to ``wx.ScrolledPanel.__init__``
+        :arg minHeight: Minimum height of each row
         """
+        self.__minHeight   = minHeight
         self.__widgSizer   = wx.BoxSizer(wx.VERTICAL)
         self.__sizer       = wx.BoxSizer(wx.VERTICAL)
 
@@ -290,6 +293,19 @@ class WidgetList(scrolledpanel.ScrolledPanel):
         colPanel.Bind(togglepanel.EVT_TOGGLEPANEL_EVENT, self.__onGroupExpand)
 
 
+    def GetWidgets(self, groupName=None):
+        """Returns a list containing all of the widgets that have been added
+        to this ``WidgetList``.
+
+        :arg groupName: If provided, only widgets in the specified group will
+                        be returned. Otherwise, ungrouped widgets are returned.
+        """
+        if groupName is None: widgDict = self.__widgets
+        else:                 widgDict = self.__groups[groupName].widgets
+        widgets = [w.widget for w in widgDict.values()]
+        return widgets
+
+
     def AddWidget(self, widget, displayName, tooltip=None, groupName=None):
         """Add an arbitrary widget to the property list.
 
@@ -340,6 +356,10 @@ class WidgetList(scrolledpanel.ScrolledPanel):
             for child in widget.GetChildren():
                 child.GetWindow().Reparent(widgPanel)
         else:
+            w, h = widget.GetBestSize().Get()
+            if self.__minHeight > h:
+                h = self.__minHeight
+            widget.SetMinSize( (w, h))
             widget.Reparent(widgPanel)
 
         label = wx.StaticText(widgPanel,
@@ -462,10 +482,9 @@ class WidgetList(scrolledpanel.ScrolledPanel):
 
     def Clear(self):
         """Removes and destroys all widgets and groups. """
-        keys = self.__widgets.keys()
-        for key in keys:
+        for key in list(self.__widgets.keys()):
             widg = self.__widgets.pop(key)
-            self.__propSizer.Detach(widg.sizer)
+            self.__widgSizer.Detach(widg.sizer)
             widg.Destroy()
 
         for group in self.GetGroups():
